@@ -20,6 +20,9 @@
 
 #include <osmocom/ctrl/control_if.h>
 
+#include <osmocom/gtp/gtp.h>
+#include <osmocom/gtp/pdp.h>
+
 #include <osmocom/sgsn/sgsn.h>
 #include <osmocom/sgsn/signal.h>
 #include <osmocom/sgsn/gprs_utils.h>
@@ -31,9 +34,6 @@
 #include <osmocom/sgsn/pdpctx.h>
 #include <osmocom/sgsn/mmctx.h>
 
-#include <gtp.h>
-#include <pdp.h>
-
 #include <arpa/inet.h>
 
 #include <time.h>
@@ -92,7 +92,7 @@ static int cdr_snprintf_mm(char *buf, size_t size, const char *ev,
 		mmctx->imei,
 		mmctx->msisdn,
 		mmctx->gb.cell_id,
-		mmctx->ra.lac,
+		mmctx->ra.lac.lac,
 		mmctx->hlr,
 		ev);
 	return ret;
@@ -194,7 +194,7 @@ static int cdr_snprintf_pdp(char *buf, size_t size, const char *ev,
 		pdp->mm ? pdp->mm->imei : "N/A",
 		pdp->mm ? pdp->mm->msisdn : "N/A",
 		pdp->mm ? pdp->mm->gb.cell_id : -1,
-		pdp->mm ? pdp->mm->ra.lac : -1,
+		pdp->mm ? pdp->mm->ra.lac.lac : -1,
 		pdp->mm ? pdp->mm->hlr : "N/A",
 		ev,
 		(unsigned long ) duration,
